====================
People behind ASpecD
====================

Who are the people behind the ASpecD framework?

The ASpecD framework is the result of over a decade of personal development in the field of data analysis software of its main author and maintainer, **Till Biskup**. For more information, you may want to check out my `personal homepage <https://www.till-biskup.de/>`_ and my webpage on `reproducible research <https://www.reproducible-research.de/>`_.

The ideas presented have evolved over more than a decade, and many people have helped shape the ideas and implemented parts of previous programs eventually leading to the framework. To name the most important persons, in chronological order of their contributions: T. Berthold, B. Paulus, D. Meyer.

One person deserves special mentioning: J. Popp, author of the `trepr package <https://pypi.org/project/trepr/>`_. She was the first actual user and early adopter of the ASpecD framework. Many ideas have been sharpened and streamlined in frequent discussions with her.
